==> haskell-digest-0.0.1.2-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 digest
version:              0.0.1.2
visibility:           public
id:                   digest-0.0.1.2-Bwle4kRYTmNK4uaWg48glg
key:                  digest-0.0.1.2-Bwle4kRYTmNK4uaWg48glg
license:              BSD-3-Clause
copyright:            (c) 2009 Eugene Kirpichov
maintainer:           Eugene Kirpichov <ekirpichov@gmail.com>
author:               Eugene Kirpichov <ekirpichov@gmail.com>
stability:            provisional
synopsis:
    Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.

description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:             Cryptography
abi:                  b572399b83fd40ff1d539407cd17bf2a
exposed:              True
exposed-modules:      Data.Digest.Adler32 Data.Digest.CRC32
import-dirs:          /usr/lib/ghc-8.10.4/site-local/digest-0.0.1.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/digest-0.0.1.2
hs-libraries:         HSdigest-0.0.1.2-Bwle4kRYTmNK4uaWg48glg
extra-libraries:      z
includes:             zlib.h
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:         /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-digest-0.0.1.2-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-digest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 digest
version:              0.0.1.2
visibility:           public
id:                   digest-0.0.1.2-HzTusmq5AUc14HOafUvYmM
key:                  digest-0.0.1.2-HzTusmq5AUc14HOafUvYmM
license:              BSD-3-Clause
copyright:            (c) 2009 Eugene Kirpichov
maintainer:           Eugene Kirpichov <ekirpichov@gmail.com>
author:               Eugene Kirpichov <ekirpichov@gmail.com>
stability:            provisional
synopsis:
    Various cryptographic hashes for bytestrings; CRC32 and Adler32 for now.

description:
    This package provides efficient cryptographic hash implementations for
    strict and lazy bytestrings. For now, CRC32 and Adler32 are supported;
    they are implemented as FFI bindings to efficient code from zlib.

category:             Cryptography
abi:                  2beef6e3308bdc1e2d11916ab0ddd30a
exposed:              True
exposed-modules:      Data.Digest.Adler32 Data.Digest.CRC32
import-dirs:          /usr/lib/ghc-8.10.5/site-local/digest-0.0.1.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/digest-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/digest-0.0.1.2
hs-libraries:         HSdigest-0.0.1.2-HzTusmq5AUc14HOafUvYmM
extra-libraries:      z
includes:             zlib.h
depends:              base-4.14.2.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-digest/html/digest.haddock
haddock-html:         /usr/share/doc/haskell-digest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
